==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebGridGroupingStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSortingStrategyDescriptionMetadata } from "./WebGridSortingStrategyDescriptionMetadata";
import { WebGridGroupingStrategyDescription } from "./WebGridGroupingStrategyDescription";
/**
 * @hidden
 */
export let WebGridGroupingStrategyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridGroupingStrategyDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridGroupingStrategyDescriptionMetadata.a == null) {
                WebGridGroupingStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridGroupingStrategyDescriptionMetadata.c(WebGridGroupingStrategyDescriptionMetadata.a);
            }
            if (a.j(WebGridGroupingStrategyDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridGroupingStrategyDescriptionMetadata.a);
        }
        static c(a) {
            WebGridSortingStrategyDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridGroupingStrategy");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
        }
        static d(a) {
            WebGridGroupingStrategyDescriptionMetadata.b(a);
            a.aa("WebGridGroupingStrategy", () => new WebGridGroupingStrategyDescription());
            a.z("WebGridGroupingStrategy", WebGridGroupingStrategyDescriptionMetadata.a);
        }
    }
    WebGridGroupingStrategyDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridGroupingStrategyDescriptionMetadata, 'WebGridGroupingStrategyDescriptionMetadata');
    WebGridGroupingStrategyDescriptionMetadata.a = null;
    return WebGridGroupingStrategyDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridGroupingStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSortingStrategyDescriptionMetadata } from "./WebGridSortingStrategyDescriptionMetadata";
import { WebGridGroupingStrategyDescription } from "./WebGridGroupingStrategyDescription";
/**
 * @hidden
 */
export let WebGridGroupingStrategyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridGroupingStrategyDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridGroupingStrategyDescriptionMetadata.a == null) {
                WebGridGroupingStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridGroupingStrategyDescriptionMetadata.c(WebGridGroupingStrategyDescriptionMetadata.a);
            }
            if (a.k(WebGridGroupingStrategyDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridGroupingStrategyDescriptionMetadata.a);
        }
        static c(a) {
            WebGridSortingStrategyDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridGroupingStrategy");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebGridGroupingStrategyDescriptionMetadata.b(a);
            a.ac("WebGridGroupingStrategy", () => new WebGridGroupingStrategyDescription());
            a.ab("WebGridGroupingStrategy", WebGridGroupingStrategyDescriptionMetadata.a);
        }
    }
    WebGridGroupingStrategyDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridGroupingStrategyDescriptionMetadata, 'WebGridGroupingStrategyDescriptionMetadata');
    WebGridGroupingStrategyDescriptionMetadata.a = null;
    return WebGridGroupingStrategyDescriptionMetadata;
})();
